# -*- coding: utf-8 -*-
# -*- Python Version: 2.7 -*-

"""Package: Honeybee-PH-Utils

These classes are designed to be used within a Honeybee-editing environment, such as Rhino or 
Grasshopper. These modules include a variety of helper functions used throughout HBPH.
"""

# load all functions that extends honeybee core library
# Make sure the load `honeybee_energy` before anything else to avoid import errors.
import honeybee_energy._extend_honeybee
